@@ -218,10 +218,7 @@ main (int argc, char *argv[])
 #endif
 
   context = g_option_context_new (NULL);
-#if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif
-
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 #ifdef WITH_SMCLIENT
   g_option_context_add_group (context, egg_sm_client_get_option_group ());
@@ -288,8 +285,8 @@ main (int argc, char *argv[])
 		    G_CALLBACK (move_cb), NULL);
   g_signal_connect (G_OBJECT (game_area), "configure-event",
 		    G_CALLBACK (resize_cb), NULL);
-  g_signal_connect (G_OBJECT (game_area), "expose-event",
-		    G_CALLBACK (expose_cb), NULL);
+  g_signal_connect (G_OBJECT (game_area), "draw",
+		    G_CALLBACK (draw_cb), NULL);
 
   gridframe = games_grid_frame_new (GAME_WIDTH, GAME_HEIGHT);
   gtk_container_add (GTK_CONTAINER (gridframe), game_area);
