@@ -22,7 +22,13 @@
 #include <errno.h>
 
 #include <gtk/gtk.h>
+
+#if GTK_CHECK_VERSION (2, 90, 7)
+#define GDK_KEY(symbol) GDK_KEY_##symbol
+#else
 #include <gdk/gdkkeysyms.h>
+#define GDK_KEY(symbol) GDK_##symbol
+#endif
 
 #ifdef HAVE_GNOME
 #include <gconf/gconf-client.h>
@@ -39,7 +45,7 @@
 
 #define GAMES_CONF_GET_PRIVATE(that)(G_TYPE_INSTANCE_GET_PRIVATE ((that), GAMES_TYPE_CONF, GamesConfPrivate))
 
-struct _GamesConfPrivate {
+struct GamesConfPrivate {
   char *game_name;
 
 #ifdef HAVE_GNOME
@@ -586,7 +592,7 @@ games_conf_shutdown (void)
  * Returns the default #GamesConf instance. games_conf_init() must have
  * been called before this!
  *
- * Returns: a #GamesConf (no reference)
+ * Returns: (transfer none): a #GamesConf (no reference)
  */
 GamesConf *
 games_conf_get_default (void)
@@ -655,9 +661,9 @@ loser:
 
 /**
  * games_conf_get_string:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
- * @error: a location for a #GError
+ * @error: (allow-none): a location for a #GError
  *
  * Returns the string associated with @key in @group, or %NULL if
  * @key is not set, or an error occurred
@@ -685,7 +691,7 @@ games_conf_get_string (const char *group, const char *key,
 
 /**
  * games_conf_get_string_with_default:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @def_value: the default value
  *
@@ -714,7 +720,7 @@ games_conf_get_string_with_default (const char *group, const char *key,
 
 /**
  * games_conf_set_string:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @value: the value to store
  *
@@ -740,15 +746,15 @@ games_conf_set_string (const char *group, const char *key,
 
 /**
  * games_conf_get_string_list:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
- * @len: a location to store the length of the returned array
- * @error: a location for a #GError
+ * @n_values: a location to store the length of the returned array
+ * @error: (allow-none): a location for a #GError
  *
  * Returns the string array associated with @key in @group, or %NULL if
  * @key is not set, or an error occurred
  *
- * Returns: a newly allocated string array, or %NULL
+ * Returns: (transfer full): a newly allocated string array, or %NULL
  */
 char **
 games_conf_get_string_list (const char *group, const char *key,
@@ -789,7 +795,7 @@ games_conf_get_string_list (const char *group, const char *key,
 
 /**
  * games_conf_set_string_list:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @values: the value to store
  * @n_values: the length of the @values array
@@ -827,9 +833,9 @@ games_conf_set_string_list (const char *group, const char *key,
 
 /**
  * games_conf_get_integer:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
- * @error: a location for a #GError
+ * @error: (allow-none): a location for a #GError
  *
  * Returns the integer associated with @key in @group, or 0 if
  * @key is not set, or an error occurred
@@ -858,7 +864,7 @@ games_conf_get_integer (const char *group, const char *key,
 
 /**
  * games_conf_get_integer_with_default:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @def_value: the default value
  *
@@ -886,7 +892,7 @@ games_conf_get_integer_with_default (const char *group, const char *key,
 
 /**
  * games_conf_set_integer:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @value: the value to store
  *
@@ -911,10 +917,10 @@ games_conf_set_integer (const char *group, const char *key, int value)
 
 /**
  * games_conf_get_integer_list:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
- * @len: a location to store the length of the returned array
- * @error: a location for a #GError
+ * @n_values: a location to store the length of the returned array
+ * @error: (allow-none): a location for a #GError
  *
  * Returns the integer associated with @key in @group, or 0 if
  * @key is not set, or an error occurred
@@ -955,7 +961,7 @@ games_conf_get_integer_list (const char *group, const char *key,
 
 /**
  * games_conf_set_integer_list:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @values: the value to store
  * @n_values: the length of the @values array
@@ -993,9 +999,9 @@ games_conf_set_integer_list (const char *group, const char *key,
 
 /**
  * games_conf_get_boolean:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
- * @error: a location for a #GError
+ * @error: (allow-none): a location for a #GError
  *
  * Returns the boolean associated with @key in @group, or %FALSE if
  * @key is not set, or an error occurred
@@ -1023,8 +1029,8 @@ games_conf_get_boolean (const char *group, const char *key,
 }
 
 /**
- * games_conf_get_boolean_width_default:
- * @group: the group name, or %NULL to use the default group
+ * games_conf_get_boolean_with_default:
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @def_value: the default value
  *
@@ -1051,7 +1057,7 @@ games_conf_get_boolean_with_default (const char *group, const char *key,
 
 /**
  * games_conf_set_boolean:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @value: the value to store
  *
@@ -1077,7 +1083,7 @@ games_conf_set_boolean (const char *group, const char *key,
 
 /**
  * games_conf_get_double:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @error: a location for a #GError
  *
@@ -1113,7 +1119,7 @@ games_conf_get_double (const char *group, const char *key,
 
 /**
  * games_conf_set_double:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @value: the value to store
  *
@@ -1141,9 +1147,9 @@ games_conf_set_double (const char *group, const char *key, double value)
 
 /**
  * games_conf_get_keyval:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
- * @error: a location for a #GError
+ * @error: (allow-none): a location for a #GError
  *
  * Returns the keyboard key associated with @key in @group, or 0 if
  * @key is not set, or an error occurred
@@ -1159,7 +1165,7 @@ games_conf_get_keyval (const char *group, const char *key,
 #ifdef HAVE_GNOME
   GConfValueType type;
   char *key_name, *value;
-  guint keyval = GDK_VoidSymbol;
+  guint keyval = GDK_KEY (VoidSymbol);
 
   key_name = get_gconf_key_name (group, key);
   type = get_gconf_value_type_from_schema (key_name);
@@ -1168,7 +1174,7 @@ games_conf_get_keyval (const char *group, const char *key,
   if (type == GCONF_VALUE_STRING) {
     value = gconf_client_get_string (priv->gconf_client, key_name, error);
     if (!value) {
-      keyval = GDK_VoidSymbol;
+      keyval = GDK_KEY (VoidSymbol);
     } else {
       keyval = gdk_keyval_from_name (value);
       g_free (value);
@@ -1176,7 +1182,7 @@ games_conf_get_keyval (const char *group, const char *key,
   } else if (type == GCONF_VALUE_INT) {
     keyval = gconf_client_get_int (priv->gconf_client, key_name, error);
     if (*error || keyval == 0)
-      keyval = GDK_VoidSymbol;
+      keyval = GDK_KEY (VoidSymbol);
   } else {
     g_warning ("Unknown value type for key %s\n", key_name);
   }
@@ -1186,7 +1192,7 @@ games_conf_get_keyval (const char *group, const char *key,
   return keyval;
 #else
   char *value;
-  guint keyval = GDK_VoidSymbol;
+  guint keyval = GDK_KEY (VoidSymbol);
 
   value = g_key_file_get_string (priv->key_file, group, key, error);
   if (value) {
@@ -1199,8 +1205,8 @@ games_conf_get_keyval (const char *group, const char *key,
 }
 
 /**
- * games_conf_get_keyval:
- * @group: the group name, or %NULL to use the default group
+ * games_conf_get_keyval_with_default:
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @default_keyval: the default value
  *
@@ -1221,7 +1227,7 @@ games_conf_get_keyval_with_default (const char *group, const char *key,
     g_error_free (error);
     value = default_keyval;
   }
-  if (value == GDK_VoidSymbol) {
+  if (value == GDK_KEY (VoidSymbol)) {
     value = default_keyval;
   }
 
@@ -1230,7 +1236,7 @@ games_conf_get_keyval_with_default (const char *group, const char *key,
 
 /**
  * games_conf_set_keyval:
- * @group: the group name, or %NULL to use the default group
+ * @group: (allow-none): the group name, or %NULL to use the default group
  * @key: the key name
  * @value: the value to store
  *
@@ -1245,7 +1251,7 @@ games_conf_set_keyval (const char *group, const char *key, guint value)
   GConfValueType type;
   char *key_name, *name;
 
-  if (value == GDK_VoidSymbol)
+  if (value == GDK_KEY (VoidSymbol))
     return;
 
   key_name = get_gconf_key_name (group, key);
@@ -1265,7 +1271,7 @@ games_conf_set_keyval (const char *group, const char *key, guint value)
 #else
   char *name;
 
-  if (value == GDK_VoidSymbol)
+  if (value == GDK_KEY (VoidSymbol))
     return;
   
   name = gdk_keyval_name (value);
@@ -1277,7 +1283,7 @@ games_conf_set_keyval (const char *group, const char *key, guint value)
 /**
  * games_conf_add_window:
  * @window: a #GtkWindow
- * @group: the group to store the state in, or %NULL to use
+ * @group: (allow-none): the group to store the state in, or %NULL to use
  * the default group
  * 
  * Restore the window configuration, and persist changes to the window configuration:
